@@ -1,15 +1,15 @@
-from . import cfg, stacks, i_stack, i_region, events, show, ssm
+from . import cfg, stacks, i_stack, i_region, events, table, ssm
 from .tools import concurrent_exec, get_exports, show_confirm
 from .common import *
 
 
 def create():
     name = cfg.stack[0]
-    stack = i_stack.ibox_stack(name, {})
     cfg.exports = get_exports()
+    stack = i_stack.ibox_stack(name, {})
     result = stack.create()
     if result:
-        print(result)
+        pprint(result)
 
     return result
 
@@ -25,7 +25,7 @@ def update():
             return
     result = concurrent_exec('update', w_stacks, i_stack)
     if not cfg.dryrun:
-        print(result)
+        pprint(result)
 
     return result
 
@@ -38,7 +38,7 @@ def delete():
     if not show_confirm():
         return
     result = concurrent_exec('delete', w_stacks, i_stack)
-    print(result)
+    pprint(result)
 
     return result
 
@@ -47,7 +47,7 @@ def cancel_update():
     w_stacks = stacks.get()
     cfg.exports = get_exports()
     result = concurrent_exec('cancel_update', w_stacks, i_stack)
-    print(result)
+    pprint(result)
 
     return result
 
@@ -56,7 +56,7 @@ def continue_update():
     w_stacks = stacks.get()
     cfg.exports = get_exports()
     result = concurrent_exec('continue_update', w_stacks, i_stack)
-    print(result)
+    pprint(result)
 
     return result
 
@@ -99,14 +99,14 @@ def dash():
 
 def show_table():
     w_stacks = stacks.get()
-    table = show.table(list(w_stacks.values()))
-    print(table)
+    s_table = table.get(list(w_stacks.values()))
+    print(s_table)
 
-    return table
+    return s_table
 
 
 def ssm_setup():
-    w_stacks = stacks.get()
+    w_stacks = stacks.get(exit_if_empty=False)
     result = concurrent_exec(
         'ssm_setup', {k: w_stacks for k in cfg.regions}, i_region)
     pprint(result)
@@ -132,3 +132,26 @@ def ssm_show():
         'ssm_get', {k: w_stacks for k in regions}, i_region)
     result = ssm.show(result)
     print(result)
+
+
+def r53():
+    w_stacks = stacks.get()
+    cfg.exports = get_exports()
+    result = concurrent_exec('r53', w_stacks, i_stack)
+    pprint(result)
+
+
+def replicate():
+    regions = ssm.get_setupped_regions() if not cfg.regions else cfg.regions
+
+    if cfg.no_replicate_current:
+        try:
+            regions.remove(cfg.boto3.region_name)
+        except Exception as e:
+            pass
+
+    result = concurrent_exec(
+        'replicate', {k: {} for k in regions}, i_region)
+    pprint(result)
+
+    return result
