@@ -12,20 +12,22 @@ def _get_ssm_parameter(ssm, param):
     return resp['Parameter']['Value']
 
 
-def get_setupped_regions(stack=None):
+def get_setupped_regions():
     boto3 = myboto3()
     ssm = boto3.client('ssm')
 
     try:
-        rgs = _get_ssm_parameter(ssm, f'{cfg.SSM_BASE_PATH}/{stack}/regions')
-    except Exception as e:
         rgs = _get_ssm_parameter(ssm, f'{cfg.SSM_BASE_PATH}/regions')
+    except Exception:
+        return []
 
     return rgs.split()
 
 
 def get_by_path(iregion, path):
+    stacks_list = tuple(iregion.bdata.keys())
     params = {}
+
     paginator = iregion.ssm.get_paginator('get_parameters_by_path')
     response_iterator = paginator.paginate(Path=path, Recursive=True)
 
@@ -35,8 +37,7 @@ def get_by_path(iregion, path):
             name = '/'.join(name.split('/')[-2:])
             value = p['Value']
 
-            stacks_list = tuple(iregion.bdata.keys())
-            if not stacks_list or name.startswith(stacks_list):
+            if 'ALL' in iregion.cfg.type or name.startswith(stacks_list):
                 params[name] = value
 
     return params
